from .__utils import path_converter

API_URL = f'https://disdial.onrender.com/data'
API_URL2 = f'https://disdial.onrender.com/all'
# API_URL = f'https://127.0.0.1:5000/data'

LOGS_FILE_PATH = path_converter("data/logs.txt")
JSON_FILE_PATH = path_converter("data/config.json")